Exceptions
===========

Exceptions which are used throughout the codebase

.. py:module:: pubtools._quay.exceptions

.. autoclass:: ManifestTypeError
.. autoclass:: RegistryAuthError
.. autoclass:: BadPushItem
.. autoclass:: InvalidTargetSettings
.. autoclass:: InvalidRepository
.. autoclass:: SigningError
